"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const http_1 = __importDefault(require("http"));
const fs_1 = __importDefault(require("fs"));
const log_formatter_1 = __importDefault(require("log-formatter"));
const NodeServicesManager_1 = require("./../Node/NodeServicesManager");
/**
 * NodeServicesManager的基础上添加的功docker进行健康检查的服务器。
 * 服务器监听在 /tmp/service_starter_health_checking.sock
 */
class DockerServicesManager extends NodeServicesManager_1.NodeServicesManager {
    constructor(_config = {}) {
        super(_config);
        if (_config.startHealthChecking !== false && ['linux', 'darwin'].includes(process.platform)) { // 配置健康检查服务
            const port = '/tmp/service_starter_health_checking.sock'; // 要被监听的端口
            fs_1.default.unlinkSync(port); // 删除之前的端口，避免被占用
            // 创建服务器
            const server = http_1.default.createServer(async (req, res) => {
                const result = await this.healthCheck();
                res.end(result.description);
            });
            server.once('error', err => {
                log_formatter_1.default.error
                    .location.white
                    .title.red
                    .content.red(this.name, '健康检查服务器出现异常：', err);
            });
            server.listen(port);
        }
    }
}
exports.DockerServicesManager = DockerServicesManager;
